pilas.motores.motor_qt.MusicaPhonon

Package pilas :: Package motores :: Module motor_qt :: Class MusicaPhonon |
[hide private]
[frames] | no frames]

# Class MusicaPhonon

source code

    SonidoPhonon --+
                   |
                  MusicaPhonon

Instance Methods | [hide private]
__init__(self, media, ruta) | source code
Inherited from `SonidoPhonon`: `continuar`, `detener`, `pausar`, `reproducir`

Class Variables | [hide private]
Inherited from `SonidoPhonon`: `deshabilitado`

Method Details | [hide private]

### __init__(self, media, ruta) (Constructor) | source code
Overrides: SonidoPhonon.__init__